==> ideaIC-143.1453.5-sources.jar: org/jetbrains/plugins/groovy/mvc/projectView/MethodNode.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.plugins.groovy.mvc.projectView;

import com.intellij.ide.projectView.ViewSettings;
import com.intellij.ide.util.treeView.AbstractTreeNode;
import com.intellij.openapi.module.Module;
import com.intellij.psi.PsiElement;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.typedef.members.GrMethod;

import java.util.Collection;

/**
 * @author Dmitry Krasilschikov
 */
public class MethodNode extends AbstractMvcPsiNodeDescriptor {
  public MethodNode(@NotNull final Module module,
                   @NotNull final GrMethod method,
                   @Nullable final String locationMark,
                   @Nullable final ViewSettings viewSettings) {
    super(module, viewSettings, new NodeId(method, locationMark), METHOD);
  }

  @Override
  protected String getTestPresentationImpl(@NotNull final NodeId nodeId, @NotNull final PsiElement psiElement) {
    return "GrMethod: " + ((GrMethod)psiElement).getName();
  }

  @Override
  protected Collection<AbstractTreeNode> getChildrenImpl() {
    return null;
  }

}

==> ideaIC-173.4301.1-sources.jar: org/jetbrains/plugins/groovy/mvc/projectView/MethodNode.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.plugins.groovy.mvc.projectView;

import com.intellij.ide.projectView.ViewSettings;
import com.intellij.ide.util.treeView.AbstractTreeNode;
import com.intellij.openapi.module.Module;
import com.intellij.psi.PsiElement;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.typedef.members.GrMethod;

import java.util.Collection;

/**
 * @author Dmitry Krasilschikov
 */
public class MethodNode extends AbstractMvcPsiNodeDescriptor {
  public MethodNode(@NotNull final Module module,
                    @NotNull final GrMethod method,
                    @Nullable final ViewSettings viewSettings) {
    super(module, viewSettings, method, METHOD);
  }

  @Override
  protected String getTestPresentationImpl(@NotNull final PsiElement psiElement) {
    return "GrMethod: " + ((GrMethod)psiElement).getName();
  }

  @Override
  protected Collection<AbstractTreeNode> getChildrenImpl() {
    return null;
  }

}
